==> haskell-summoner-tui-2.0.1.1-496-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-3xJuoobNcqP2NN50JnCLdo
key:                  summoner-tui-2.0.1.1-3xJuoobNcqP2NN50JnCLdo
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  d79d347b2cf0b609b5ceb912050e5d00
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.0.2/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-3xJuoobNcqP2NN50JnCLdo
depends:
    base-4.15.1.0 relude-0.7.0.0-C0oEuHJqzL8JB0mtmrYX38
    brick-0.71.1-1VtylvcFxtNAkb90QiDkvr
    colourista-0.1.0.2-D4bOYyBhyc5Bhb2c6cO8Mv directory-1.3.6.2
    microlens-0.4.13.1-AoR6D5midYZB5ErWoiySs4
    microlens-th-0.4.3.14-AKNvIwdJVYaDQVlM4liVo5
    summoner-2.0.1.1-JWIKPcT241XKOc7cXQUvgJ text-1.2.5.0
    validation-selective-0.1.0.2-C669mfsPiaG7FT3BtK6aEZ
    vty-5.38-4Mh2CNJWD2pI3DdZnHfdXD

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-tui-2.0.1.1-502-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-2LU7gJ1sorF8xmetpIEilr
key:                  summoner-tui-2.0.1.1-2LU7gJ1sorF8xmetpIEilr
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  289156af8bede3e2af4d24ba4b9b7b60
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.0.2/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-2LU7gJ1sorF8xmetpIEilr
depends:
    base-4.15.1.0 relude-0.7.0.0-FZovChRhYPtIKr5gYwBa0j
    brick-0.71.1-6HuhyxOJBPjF3Zt84wepgO
    colourista-0.1.0.2-23HNAqxIjkK91h837YPLSv directory-1.3.6.2
    microlens-0.4.13.1-AoR6D5midYZB5ErWoiySs4
    microlens-th-0.4.3.14-AKNvIwdJVYaDQVlM4liVo5
    summoner-2.0.1.1-HK1urIMFkOmEgzEloT1ixD text-1.2.5.0
    validation-selective-0.1.0.2-2cFJbsM5nyZ5Agqsg3mhoa
    vty-5.38-58dhVqUy5myGVjMHQESSWU

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
